CradminDateSelectorHiddenIsoDate | django_cradmin API Document

    import CradminDateSelectorHiddenIsoDate from 'django_cradmin/scripts/django_cradmin/components/CradminDateSelectorHiddenIsoDate.jsx'

public class | source

# CradminDateSelectorHiddenIsoDate

#### Extends:

react~React.Component → CradminDateSelectorHiddenIsoDate

## Static Member Summary

Static Public Members
public static get | defaultProps: * |

## Constructor Summary

Public Constructor
public | constructor(props: *) |

## Member Summary

Public Members
public | logger: * |
public | state: * |

## Method Summary

Public Methods
public | render(): * |

## Static Public Members

### public static get defaultProps: * source

## Public Constructors

### public constructor(props: *) source

#### Params:

Name | Type | Attribute | Description
props | * |  |

## Public Members

### public logger: * source

### public state: * source

## Public Methods

### public render(): * source

#### Return:

*